@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.70
+ version: 0.81
  Written in Qt 4.4
 
                         graphicswidget.cpp description
                              -------------------
-    copyright            : (C) 2005-2009 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -50,7 +50,7 @@ GraphicsWidget::GraphicsWidget( QGraphicsScene *sc, MainWindow* par)  : QGraphic
 	moving=0;
 	timerId=0;
 	layoutType=0;
-	m_numberColor="black";
+
 	m_nodeLabel="";
 	
 	zoomIndex=3;
@@ -78,7 +78,7 @@ void GraphicsWidget::paintEvent ( QPaintEvent * event ){
 	Clears the scene 
 */
 void GraphicsWidget::clear() {
-	qDebug("GW: clear()");
+	//qDebug("GW: clear()");
 	int i=0;
 	nodeVector.clear();
 	QList<QGraphicsItem *> allItems=scene()->items();
@@ -87,8 +87,8 @@ void GraphicsWidget::clear() {
 		scene()->removeItem (item);
 		i++;
 	}
-	qDebug("GW: Removed %i items from scene. Scene items now: %i ",i, scene()->items().size());
-	qDebug("GW: items now: %i ", this->items().size());
+	//qDebug("GW: Removed %i items from scene. Scene items now: %i ",i, scene()->items().size());
+	//qDebug("GW: items now: %i ", this->items().size());
 }
 
 
@@ -105,47 +105,46 @@ void GraphicsWidget::clear() {
 
 */
 void GraphicsWidget::drawNode(
-								int num, int size, QString nodeColor, 
-								QString nodeLabel, QString labelColor, 
-								QPointF p, 
-								QString shape, 
-								bool showLabels, bool numberInsideNode, bool showNumbers
-								) {
+		int num, int size, QString nodeColor,
+		QString numberColor, int numberSize,
+		QString nodeLabel, QString labelColor, int labelSize,
+		QPointF p,
+		QString shape,
+		bool showLabels, bool numberInsideNode, bool showNumbers
+		) {
 	qDebug()<< "GW: drawNode(): drawing new node at: " 
-			<< p.x() << ", "<< p.y() 
-			<< " First we create node, then label/number, finally move node" ;
+			<< p.x() << ", "<< p.y() ;
+
 
 	if (numberInsideNode)
 		size = size +3;
 	
 	Node *jim= new Node (
-						this, 
-						num, size, nodeColor, shape, 
-						numberInsideNode, m_labelDistance, m_numberDistance, 
-						p
-						);
+			this,
+			num, size, nodeColor, shape,
+			numberInsideNode, m_labelDistance, m_numberDistance,
+			p
+			);
 
 	//Drawing node label - label will be moved by the node movement (see last code line in this method)
-	NodeLabel *labelJim = new  NodeLabel (jim, nodeLabel, scene() );
+	NodeLabel *labelJim = new  NodeLabel (jim, labelSize, nodeLabel, scene() );
 	labelJim -> setDefaultTextColor (labelColor);
 	labelJim -> setTextInteractionFlags(Qt::TextEditorInteraction);
 	
-	if (showLabels) 
-		qDebug()<< "GW: drawNode: display label " <<  nodeLabel.toAscii() << " for node " << num;
+	if (showLabels) {
+		//qDebug()<< "GW: drawNode: display label " <<  nodeLabel.toAscii() << " for node " << num;
+	}
 	else {
-		qDebug()<<"GW: drawNode: hiding label for node " << num;
+		//qDebug()<<"GW: drawNode: hiding label for node " << num;
 		labelJim->hide();
 	}
 
 	// drawing node number - label will be moved by the node movement (see last code line in this method)
-	int numSize;
-	if (!numberInsideNode)
-		numSize = size + 2;
-	else 
-		numSize = size;
+	if (numberInsideNode)
+		numberSize = size-2;
 		
-	NodeNumber *numberJim = new  NodeNumber ( jim, numSize, QString::number(num), scene() );
-	numberJim -> setDefaultTextColor (m_numberColor);
+	NodeNumber *numberJim = new  NodeNumber ( jim, numberSize, QString::number(num), scene() );
+	numberJim -> setDefaultTextColor (numberColor);
 	
 	if (!showNumbers){
 		numberJim->hide();
@@ -156,7 +155,7 @@ void GraphicsWidget::drawNode(
 	nodeVector.push_back(jim);
 	
 	//finally, move the node where it belongs!
-	jim -> setPos(p.x(), p.y());
+	jim -> setPos( p.x(), p.y());
 }
 
 
@@ -302,7 +301,7 @@ void GraphicsWidget::edgeClicked(Edge *edge){
 
 */
 void GraphicsWidget::nodeMoved(int number, int x, int y){
-	qDebug ("GW: nodeMoved() for %i with %i, %i. Emitting updateNodeCoords() signal", number, x,y);
+	//qDebug ("GW: nodeMoved() for %i with %i, %i. Emitting updateNodeCoords() signal", number, x,y);
 	emit updateNodeCoords(number, x, y);
 }
 
@@ -618,7 +617,7 @@ Node* GraphicsWidget::hasNode( QString text ){
 	bool ok = false;
 	for ( it=nodeVector.begin() ; it < nodeVector.end(); it++ ) {
 		if ( 	(*it)->nodeNumber()==text.toInt(&ok, 10)  || 
-				(*it)->label().contains (text, Qt::CaseInsensitive)
+				(*it)->labelText().contains (text, Qt::CaseInsensitive)
 			 ) {
 			qDebug() << "GW: hasNode(): Node " << text << " found!";
 			markedNodeExists=true;
@@ -707,42 +706,53 @@ void GraphicsWidget::clearBackgrCircles(){
 		Yes, we make a full circle! :) 
 */
 void GraphicsWidget::mouseDoubleClickEvent ( QMouseEvent * e ) {
-	qDebug("GW: mouseDoubleClickEvent() double click detected!");
+
 	if ( QGraphicsItem *item= itemAt(e->pos() ) ) {
 		if (Node *node = qgraphicsitem_cast<Node *>(item)) {
 			Q_UNUSED(node);
-			qDebug("double click on a node... Cant create new one!");
+			qDebug() << "GW: mouseDoubleClickEvent() double click on a node detected!"
+					<< " Cant create new one!";
 			return;
 		}
 	}
 
 	QPointF p = mapToScene(e->pos());
-	qDebug("GW: mouseDoubleClickEvent(): Emit a signal to MW to create a new node in graph. e->pos() (%i, %i) at %f, %f", e->pos().x(),e->pos().y(), p.x(),p.y());
+	qDebug()<< " GW: mouseDoubleClickEvent():double click detected on empty space. "
+	       << " Emitting signal to MW to create a new vertex in graph. e->pos() "
+	       << e->pos().x() << ", "<< e->pos().y() << ", "<< p.x() << ", " <<p.y();
 	emit userDoubleClicked(-1, p);
 	qDebug("GW: mouseDoubleClickEvent(): Scene and GW items now: %i and %i. Emitting Changed() signal... ", scene()->items().size(), items().size());
 }
 
 
 
+void GraphicsWidget::mousePressEvent( QMouseEvent * e ) {
+	QPointF p = mapToScene(e->pos());
+	if ( QGraphicsItem *item= itemAt(e->pos() ) ) {
+		if (Node *node = qgraphicsitem_cast<Node *>(item)) {
+			Q_UNUSED(node);
+			qDebug() << "GW: mousePressEvent() single click detected on a node at pos  "
+					<< e->pos().x() << ","<< e->pos().y() << " or "<<  p.x() << ","<<p.y();
+			QGraphicsView::mousePressEvent(e);
+			return;
+		}
+		if (Edge *edge= qgraphicsitem_cast<Edge *>(item)) {
+			Q_UNUSED(edge);
+			qDebug() << "GW: mousePressEvent() single click detected on an edge at pos  "
+					<< e->pos().x() << ","<< e->pos().y() << " or "<<  p.x() << ","<<p.y();
 
-//void GraphicsWidget::mousePressEvent( QMouseEvent * e ) {
-	//QPointF p = mapToScene(e->pos());
-	//qDebug() << "GW: mousePressEvent() single click detected at " 
-		//<< e->pos().x() << ","<< e->pos().y() << " or "<<  p.x() << ","<<p.y();
-	//if ( QGraphicsItem *item= itemAt(e->pos() ) ) {
-		//if (Node *node = qgraphicsitem_cast<Node *>(item)) {
-			//Q_UNUSED(node);
-			//QGraphicsView::mousePressEvent(e);
-			//return;
-		//}
-	//}
-	//else{
-		//qDebug() << "GW: mousePressEvent(). No item here. Maybe start a selection rectangle? " 
-				//<< "I will save this pos";
-		//startPoint =  
-	//} 
+			QGraphicsView::mousePressEvent(e);
+			return;
+		}
+	}
+	else{
+		qDebug() << "GW: mousePressEvent(). No item here. "
+				<< "Starting a new selection rectangle or a new node";
+		this->scene()->clearSelection();
+		QGraphicsView::mousePressEvent(e);
+	} 
 
-//}
+}
 
 
 
@@ -793,62 +803,10 @@ void GraphicsWidget::openEdgeContextMenu(){
 
 
 
-/** 
-	This slot is activated when the user clicks on the relevant MainWindow checkbox (SpringEmbedder, Fruchterman) to start or stop 
-	the movement of nodes, according to the requested model. 
-	state: toggle 
-	type:  controls the type of model requested.
-*/
-void GraphicsWidget::nodeMovement(int state, int type){
-	qDebug("GW: startNodeMovement()");	
-	if (state == Qt::Checked){
-		dynamicMovement = TRUE;
-		layoutType=type;
-		if (!timerId) {
-			timerId = startTimer(100);	
-			qDebug("GW: startTimer()");
-		}
-	}
-	else
-		dynamicMovement = FALSE;
-}
 
 
 
 
-/**	This method is called automatically when a QTimerEvent occurs
-	It makes all nodes calculate the forces applied to them 
-*/
-void GraphicsWidget::timerEvent(QTimerEvent *event) {	
-	qDebug("GW: timerEvent()");
-	Q_UNUSED(event);
-	QList<Node *> nodes;
-
- 	foreach (Node *node, nodeVector) {
-		switch (layoutType){
-			case 1: 
-				node->calculateForcesSpringEmbedder(dynamicMovement);
-				break;
-			case 2: 
-				node->calculateForcesFruchterman(dynamicMovement);
-				break;
-		
-		}
-	}
-
-	bool itemsMoved = false;
-// 	foreach (Node *node, nodeVector) { 
-// 		if (node->advance()){
-// 			qDebug("GW: timerEvent() a node is moving!");
-// 			itemsMoved = true;
-// 		}
-// 	}
-
-	if (!itemsMoved) {
-		killTimer(timerId);
-		timerId = 0;
-	}
-}
 
 
 
