@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.70
+ version: 0.81
  Written in Qt 4.4
 
                         node.cpp  -  description
                         -------------------
-    copyright            : (C) 2005-2009 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -25,18 +25,17 @@
 ********************************************************************************/
 
 
+#include "node.h"
+
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
 #include <QStyleOption>
 #include <QPainter>
 #include <QDebug>
- 
 #include "graphicswidget.h"
-#include "node.h"
 #include "edge.h"
 #include "nodelabel.h"
 #include "nodenumber.h"
-
 #include <math.h> //sqrt
 
 Node::Node( GraphicsWidget* gw, int num, int size, 
@@ -44,8 +43,18 @@ Node::Node( GraphicsWidget* gw, int num, int size,
 			int ldist, int ndist, QPointF p 
 			) : graphicsWidget (gw) 
 {
+	Q_UNUSED(p);
 	graphicsWidget->scene()->addItem(this); //Without this nodes don't appear on the screen...
+
+
+#if QT_VERSION >= 0x040600
+	setFlags(ItemSendsGeometryChanges | ItemIsSelectable | ItemIsMovable); //ItemSendsGeometryChanges  introduced in Qt 4.6...
+#else
 	setFlags(ItemIsSelectable | ItemIsMovable); //Without this, the node cannot move nor be selected ...
+#endif
+
+
+	setCacheMode(DeviceCoordinateCache);
 	setAcceptsHoverEvents(true);
 	m_num=num;
 	m_size=size;
@@ -59,7 +68,9 @@ Node::Node( GraphicsWidget* gw, int num, int size,
 	m_ld=ldist;
 	m_poly_t=new QPolygon(3);
 	m_poly_d=new QPolygon(4);
-	qDebug()<< "Node: constructor: initial position at: "<< this->x()<<", "<<this->y()<< " Moving now at: "<< p.x()<<", "<<p.y();;
+	qDebug()<< "Node: constructor: initial position at: "
+			<< this->x()<<", "<<this->y()
+			<< " Will move at: "<< p.x()<<", "<<p.y();;
 
 
 
@@ -390,14 +401,14 @@ void Node::die() {
 }
 
 
-void Node::setLabel ( QString label) {
+void Node::setLabelText ( QString label) {
 	prepareGeometryChange();
 	m_label->setPlainText(label);
 	m_hasLabel=true;
 }
 
 
-QString Node::label ( ) { 
+QString Node::labelText ( ) { 
 	if (m_hasLabel) {
 		return m_label->toPlainText();				
 	}	
@@ -408,7 +419,6 @@ QString Node::label ( ) {
 
 void Node::setNumberInside (bool numIn){
 
-
 	m_isNumberInside = numIn;
 	
 	//Move its graphic number
@@ -430,51 +440,49 @@ void Node::setNumberInside (bool numIn){
 
 
 
-/** Propagates the changes to connected elements, i.e. edges, numbers, etc. 
+/** 
+ *	Propagates the changes to connected elements, i.e. edges, numbers, etc. 
  *  Checks if the node is inside the scene.
  */
 QVariant Node::itemChange(GraphicsItemChange change, const QVariant &value) {
-// 	qDebug("Node: itemChange()");
 	QPointF newPos = value.toPointF();
+
 	switch (change) {
-		case ItemPositionHasChanged:{  //ItemPositionChange
-// 			emit adjustOutEdge();
-// 			emit adjustInEdge();
-			foreach (Edge *edge, inEdgeList) 		//Move each inEdge of this node
+	case ItemPositionHasChanged :
+		{  //ItemPositionChange
+			// 	emit adjustOutEdge();
+			// 	emit adjustInEdge();
+			foreach (Edge *edge, inEdgeList)  //Move each inEdge of this node
 				edge->adjust();
-			foreach (Edge *edge, outEdgeList)		//Move each outEdge of this node
+			foreach (Edge *edge, outEdgeList) //Move each outEdge of this node
 				edge->adjust();
-			
 			//Move its graphic number
 			if ( m_hasNumber ) 
 			{
-				qDebug()<< "Node: itemChange() moving number to " << newPos.x() << " " << newPos.y();
 				if (!m_isNumberInside) 	{ //move it outside
-						m_number -> setZValue(254);
-						m_number -> setPos( newPos.x()+m_nd, newPos.y());
-					}	 
-					else { 				//move it inside node
-						m_number -> setZValue(255);
-						m_number->setPos( newPos.x() - m_size-2, newPos.y() - m_size-2 );
-					}	 
+					m_number -> setZValue(254);
+					m_number -> setPos( newPos.x()+m_size+m_nd, newPos.y());
+									}
+				else { 	//move it inside node
+					m_number -> setZValue(255);
+					m_number -> setPos( newPos.x() - m_size-2, newPos.y() - m_size-2 );
+				}
 			}
-			
 			if (m_hasLabel) {
-				m_label->setPos( newPos.x()-2, newPos.y()+m_ld);
+				m_label->setPos( newPos.x()-2, newPos.y()+m_ld+m_size);
 			}
-				
 			if ( newPos.x() !=0 && newPos.y() != 0 ){
-				qDebug()<<  "Node: ItemChange(): Emitting nodeMoved() for "<< nodeNumber()<< " at: "<<  newPos.x()<< ", "<<  newPos.y();
 				graphicsWidget->nodeMoved(nodeNumber(), (int) newPos.x(), (int) newPos.y());	
 			}
-			else qDebug()<<  "Node: ItemChange(): Not emitting nodeMoved. Node "<< nodeNumber()<<" is at 0,0";
-
+			else qDebug()<<  "Node: ItemChange():  Not emitting nodeMoved. Node "<< nodeNumber()<<" is at 0,0";
 			break;
 		} 
-		case ItemVisibleChange: {	
+	case ItemVisibleChange:
+		{
 			return 0;
 		}
-		default: {
+	default:
+		{
 			break;
 		}
 	};
@@ -555,6 +563,17 @@ void Node::deleteOutLink(Edge *link){
 
 
 
+void Node::addLabel (NodeLabel* gfxLabel  )  { 
+	//qDebug("NODE: add label");
+	m_label=gfxLabel ;
+	m_hasLabel=true;
+}
+
+
+NodeLabel* Node::label(){
+	return m_label;
+}
+
 void Node::deleteLabel(){
 	qDebug ("Node: deleteLabel ");
 	m_hasLabel=false;
@@ -568,26 +587,22 @@ void Node::clearLabel(){
 }
 
 
-void Node::deleteNumber( ){
-	qDebug ("Node: deleteNumber ");
-	m_number->hide();
-	graphicsWidget->removeItem(m_number);	
-}
 
 
 
 
-void Node::addLabel (NodeLabel* gfxLabel  )  { 
-	qDebug("NODE: add label");
-	m_label=gfxLabel ;
-	m_hasLabel=true;
-}
-
 void Node::addNumber (NodeNumber *gfxNum ) {
 	 m_number=gfxNum ;
 	 m_hasNumber=true;
 }
 
+
+void Node::deleteNumber( ){
+	qDebug ("Node: deleteNumber ");
+	m_number->hide();
+	graphicsWidget->removeItem(m_number);	
+}
+
 // Node::~Node(){
 // /*	qDebug("~Node() calling hide()");
 // 	this->hide();
