@@ -1,11 +1,11 @@
 /****************************************************************************
 SocNetV: Social Networks Visualizer 
-version: 0.70
+version: 0.81
 Written in Qt 4.4 with KDevelop   
 
                                texteditor.cpp 
                              -------------------
-    copyright            : (C) 2005-2009 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
 *****************************************************************************/
 
@@ -297,11 +297,9 @@ QString TextEditor::strippedName(const QString &fullFileName)
 void TextEditor::about()
 {
    QMessageBox::about( this, "SocNetV Editor",
-"<b>S</b>ocial <b>N</b>etwork <b>V</b>isualiser version 0.6"
-      "<p>Written by <br>Dimitris V. Kalamaras<br>"
+" Part of <b>S</b>ocial <b>N</b>etwork <b>V</b>isualizer"
+      "<p>Developer: <br>Dimitris V. Kalamaras<br>"
       "<br>email: dimitris.kalamaras@gmail.com"
-      "<p>Last revision: Sep 2009</p>"
-      "<p>Fortune cookie:  <br>sic itur ad astra/sic transit gloria mundi?"
 
     "<p>Note: This text editor was adapted from Trolltech's application example."
 
